@@ -767,8 +767,8 @@ class fscan(Macro, Hookable):
             indepvars = SafeEvaluator({'dict': dict}).eval(
                 'dict(%s)' % args[0])  # create a dict containing the indepvars
 
-        self.motors = [item[0] for item in args[2:]]
-        self.funcstrings = [item[1] for item in args[2:]]
+        self.motors = [item[0] for item in args[2]]
+        self.funcstrings = [item[1] for item in args[2]]
 
         globals_lst = [dict(zip(indepvars, values)) for values in zip(*indepvars.values())]
         self.paths = [[SafeEvaluator(globals).eval(func) for globals in globals_lst] for func in self.funcstrings]
