@@ -472,6 +472,7 @@ class umv(Macro):
             posObj.subscribeEvent(self.positionChanged, motor)
 
     def run(self, motor_pos_list):
+        self.print_pos = True
         self.execMacro('mv', motor_pos_list)
         self.finish()
  
@@ -632,14 +633,16 @@ class ct(Macro):
         state, data = self.mnt_grp.count(integ_time)
 
         names, counts = [], []
-        for ch_info in self.mnt_grp.getChannelsInfo():
+        for ch_info in self.mnt_grp.getChannelsEnabledInfo():
             names.append('  %s' % ch_info.label)
             ch_data = data.get(ch_info.full_name)
-            if ch_info.shape > [1]:
+            if ch_data is None:
+                counts.append("<nodata>")
+            elif ch_info.shape > [1]:
                 counts.append(list(ch_data.shape))
             else:
                 counts.append(ch_data)
-        
+
         table = Table([counts], row_head_str=names, row_head_fmt='%*s',
                       col_sep='  =  ')
         for line in table.genOutput():
