@@ -31,9 +31,14 @@ from sardana.macroserver.macros.test import testRun
 from sardana.macroserver.macros.test import testStop
 
 
-@testRun(macro_params=['.1'], wait_timeout=2)
-@testRun(macro_params=['.3'], wait_timeout=2)
-@testStop(macro_params=['1'], stop_delay=.1, wait_timeout=3)
+@testRun(macro_name="ct", macro_params=['.1'], wait_timeout=2)
+@testRun(macro_name="ct", macro_params=['.3'], wait_timeout=2)
+@testStop(macro_name="ct", macro_params=['1'], stop_delay=.1, wait_timeout=3)
+# TODO: uncomment these test when bug-474 is fixed:
+# https://sourceforge.net/p/sardana/tickets/474/
+#@testRun(macro_name="uct", macro_params=['.1'], wait_timeout=2)
+#@testRun(macro_name="uct", macro_params=['.3'], wait_timeout=2)
+#@testStop(macro_name="uct", macro_params=['1'], stop_delay=.1, wait_timeout=3)
 class CtTest(RunStopMacroTestCase, unittest.TestCase):
 
     """Test of ct macro. It verifies that macro ct can be executed.
@@ -43,4 +48,4 @@ class CtTest(RunStopMacroTestCase, unittest.TestCase):
     Then it does another execution and it tests if the execution can be
     aborted.
     """
-    macro_name = "ct"
+    pass
