@@ -61,32 +61,25 @@ from IPython.core.profiledir import ProfileDirError, ProfileDir
 from IPython.core.application import BaseIPythonApplication
 from IPython.core.interactiveshell import InteractiveShell
 from IPython.utils.io import ask_yes_no as _ask_yes_no
+from IPython.utils.io import raw_input_ext as _raw_input_ext
+from IPython.utils.path import get_ipython_dir
 from IPython.utils.process import arg_split
 from IPython.utils.coloransi import TermColors
-from IPython.terminal.ipapp import TerminalIPythonApp, launch_new_instance
+from IPython.config.application import Application
+from IPython.frontend.terminal.ipapp import TerminalIPythonApp, \
+    launch_new_instance
 
-try:
-    # IPython 4.x
-    from traitlets.config.application import Application
-    from IPython.paths import get_ipython_dir
-except:
-    # IPython <4.x
-   from IPython.config.application import Application
-   from IPython.utils.path import get_ipython_dir
-
-
-import taurus
-#from taurus.core import Release as TCRelease
-
-from taurus.core.taurushelper import Factory
+from taurus.core.taurushelper import Factory, Manager, Warning
 from taurus.core.util.codecs import CodecFactory
+from taurus.core.taurushelper import setLogLevel
+
 
 # make sure Qt is properly initialized
 from taurus.external.qt import Qt
 
 from sardana.spock import exception
 from sardana.spock import colors
-from sardana.spock import release
+from sardana import release
 
 SpockTermColors = colors.TermColors
 
@@ -95,6 +88,10 @@ requirements = {
     "IPython"     : ("0.11.0", "0.12.0"),
     "Python"      : ("2.6.0", "2.6.0"),
     "PyTango"     : ("7.2.0", "7.2.3"),
+    # for the moment just for reference since itango does not provide version
+    # when using PyTango < 9 the dependency is >= 0.0.1 and < 0.1.0
+    # when using PyTango >= 9 the dependency is >= 0.1.6
+    "itango"      : ("0.0.1", "0.0.1"),
     "taurus.core" : ("3.0.0", "3.0.0")
 }
 
@@ -147,12 +144,14 @@ def ask_yes_no(prompt,default=None):
     return _ask_yes_no(prompt, default)
 
 def spock_input(prompt='',  ps2='... '):
-    return raw_input(prompt)
+    return _raw_input_ext(prompt=prompt, ps2=ps2)
 
 def translate_version_str2int(version_str):
     """Translates a version string in format x[.y[.z[...]]] into a 000000 number"""
     import math
-    parts = version_str.split('.')
+    # Get the current version number ignoring the release part ("-alpha")
+    num_version_str = version_str.split('-')[0]
+    parts = num_version_str.split('.')
     i, v, l = 0, 0, len(parts)
     if not l: return v
     while i<3:
@@ -417,7 +416,7 @@ def from_name_to_tango(name):
 #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
 
 def clean_up():
-    taurus.Manager().cleanUp()
+    Manager().cleanUp()
 
 def get_taurus_core_version():
     try:
@@ -478,6 +477,12 @@ def check_requirements():
             errMsg += "Current version is unknown (most surely too old)\n"
         errPyTango = True
 
+    # TODO: verify the version whenever itango starts to provide it
+    try:
+        import itango
+    except ImportError:
+        errMsg += "Spock needs itango version >= 0.0.1, < 0.1.0 (PyTango < 9) or version >= 0.1.6 (PyTanog >= 9). No itango installation found\n"
+
     if currTaurusCore is None:
         errMsg += "Spock needs taurus.core version >= %s. No taurus.core installation found\n" % requirements["taurus.core"][0]
         errTaurusCore = True
@@ -526,7 +531,8 @@ def _get_dev(dev_type):
     if hasattr(spock_config, taurus_dev_var):
         taurus_dev = getattr(spock_config, taurus_dev_var)
     if taurus_dev is None:
-        dev_name = getattr(spock_config, dev_type + '_name')
+        # TODO: For Taurus 4 compatibility
+        dev_name = "tango://%s" % getattr(spock_config, dev_type + '_name')
         factory = Factory()
         taurus_dev = factory.getDevice(dev_name)
         import PyTango
@@ -600,26 +606,9 @@ def unexpose_variable(name):
     user_ns = get_shell().user_ns
     del user_ns[name]
 
-def create_spock_profile(userdir, dft_profile, profile, door_name=None):
-    """Create a profile file from a profile template file """
-    if not os.path.isdir(userdir):
-        ProfileDir.create_profile_dir(userdir)
-    p_dir = ProfileDir.create_profile_dir_by_name(userdir, profile)
-    ###########################################################################
-    # NOTE: BaseIPythonApplication.config_file_name.default_value should return
-    # the config file name, but it returns an empty string instead (at least 
-    # in some cases). For now, we give a hardcoded name if it is empty
-    # TODO: Check why this is the case
-    config_file_name = BaseIPythonApplication.config_file_name.default_value 
-    config_file_name = config_file_name or 'ipython_config.py' 
-    ###########################################################################
-    abs_config_file_name = os.path.join(p_dir.location, config_file_name)
-    create_config = True
-    if os.path.isfile(abs_config_file_name):
-        create_config = ask_yes_no("Spock configuration file already exists. "\
-                                   "Do you wish to replace it?", default='y')
-    if not create_config:
-        return
+def _create_config_file(location, door_name=None):
+    config_file_name = BaseIPythonApplication.config_file_name.default_value
+    abs_config_file_name = os.path.join(location, config_file_name)
 
     src_data = """\
 \"\"\"Settings for Spock session\"\"\"
@@ -631,7 +620,8 @@ def create_spock_profile(userdir, dft_profile, profile, door_name=None):
 # door_name = {door_name}
 #
 
-import PyTango.ipython
+import itango
+
 import sardana.spock.genutils
 from sardana.spock.config import Spock
 
@@ -650,7 +640,7 @@ config.IPKernelApp.pylab = 'inline'
     # Discover door name
     #
     if door_name is None:
-        door_name = get_device_from_user("Door", profile)
+        door_name = get_device_from_user("Door")
     else:
         full_door_name, door_name, _ = from_name_to_tango(door_name)
         door_name = full_door_name
@@ -664,32 +654,65 @@ config.IPKernelApp.pylab = 'inline'
                                 macroserver_name=ms_name,
                                 door_name=door_name)
 
-    sys.stdout.write('Storing %s in %s... ' % (config_file_name, p_dir.location))
+    sys.stdout.write('Storing %s in %s... ' % (config_file_name, location))
     sys.stdout.flush()
 
+
     with file(abs_config_file_name, "w") as f:
         f.write(dest_data)
         f.close()
     sys.stdout.write(MSG_DONE + '\n')
 
-def check_for_upgrade(ipy_profile_file, ipythondir, session, profile):
-    # Check if the current profile is up to date with the spock version
+def create_spock_profile(userdir, profile, door_name=None):
+    """Create spock profile directory and configuration file from a template
+    file
+
+    :param userdir: directory where the spock profile will be created
+    :param profile: profile name
+    :param door_name: door name, if None, user will be asked for the door name
+    """
+
+    if not os.path.isdir(userdir):
+        ProfileDir.create_profile_dir(userdir)
+    p_dir = ProfileDir.create_profile_dir_by_name(userdir, profile)
+    ipy_profile_dir = p_dir.location
+
+    _create_config_file(ipy_profile_dir)
+
+def upgrade_spock_profile(ipy_profile_dir, door_name):
+    """Upgrade spock profile by recreating configuration file from scratch
+
+    :param ipy_profile_dir: directory with the spock profile
+    :param door_name: door name
+    """
+    _create_config_file(ipy_profile_dir, door_name)
+
+def check_for_upgrade(ipy_profile_dir):
+    """Check if the current profile is up to date with the spock version
+
+    :param ipy_profile_dir: directory with the spock profile
+    """
     spock_profile_ver_str = '0.0.0'
     door_name = None
 
+    config_file_name = BaseIPythonApplication.config_file_name.default_value
+    abs_config_file_name = os.path.join(ipy_profile_dir, config_file_name)
+
     # search for version and door inside the ipy_profile file
-    for i, line in enumerate(ipy_profile_file):
-        if i > 20 : break; # give up after 20 lines
-        if line.startswith('# spock_creation_version = '):
-            spock_profile_ver_str = line[line.index('=')+1:].strip()
-        if line.startswith('# door_name = '):
-            door_name = line[line.index('=')+1:].strip()
+    with file(abs_config_file_name, "r") as ipy_config_file:
+        for i, line in enumerate(ipy_config_file):
+            if i > 20 : break; # give up after 20 lines
+            if line.startswith('# spock_creation_version = '):
+                spock_profile_ver_str = line[line.index('=')+1:].strip()
+            if line.startswith('# door_name = '):
+                door_name = line[line.index('=')+1:].strip()
 
     # convert version from string to numbers
     spocklib_ver = translate_version_str2int(release.version)
     spock_profile_ver = translate_version_str2int(spock_profile_ver_str)
 
-    if spocklib_ver == spock_profile_ver:
+    if spocklib_ver == spock_profile_ver and \
+            spock_profile_ver_str.find("-alpha") == -1:
         return
     if spocklib_ver < spock_profile_ver:
         print '%sYour spock profile (%s) is newer than your spock version ' \
@@ -708,7 +731,7 @@ def check_for_upgrade(ipy_profile_file, ipythondir, session, profile):
     prompt = 'Do you wish to upgrade now (warn: this will shutdown the current spock session) ([y]/n)? '
     r = raw_input(prompt) or 'y'
     if r.lower() == 'y':
-        create_spock_profile(ipythondir, session, profile, door_name)
+        upgrade_spock_profile(ipy_profile_dir, door_name)
         sys.exit(0)
 
 def get_args(argv):
@@ -742,7 +765,7 @@ def get_args(argv):
                      'one now ([y]/n)? ' % profile
             r = raw_input(prompt) or 'y'
         if r.lower() == 'y':
-            create_spock_profile(ipython_dir, session, profile)
+            create_spock_profile(ipython_dir, profile)
         else:
             sys.stdout.write('No spock door extension profile was created. Starting normal spock...\n')
             sys.stdout.flush()
@@ -801,7 +824,6 @@ def load_ipython_extension(ipython):
     init_taurus()
 
     config = ipython.config
-
     user_ns = ipython.user_ns
     user_ns['MACRO_SERVER_NAME'] = config.Spock.macro_server_name
     user_ns['MACRO_SERVER_ALIAS'] = config.Spock.macro_server_alias
@@ -909,7 +931,7 @@ object?   -> Details about 'object'. ?object also works, ?? prints more.
     # ------------------------------------
     i_app = config.BaseIPythonApplication
     extensions = getattr(i_app, 'extensions', [])
-    extensions.extend(["PyTango.ipython", "sardana.spock"])
+    extensions.extend(["itango", "sardana.spock"])
     i_app.extensions = extensions
 
     # ------------------------------------
@@ -953,6 +975,12 @@ object?   -> Details about 'object'. ?object also works, ?? prints more.
     completer.omit__names = 2
     completer.greedy = False
 
+    # ------------------------------------
+    # InteractiveShellApp
+    # ------------------------------------
+    i_shell_app = config.InteractiveShellApp
+    i_shell_app.ignore_old_config = True
+
     # ------------------------------------
     # TerminalIPythonApp: options for the IPython terminal (and not Qt Console)
     # ------------------------------------
@@ -1040,7 +1068,7 @@ object?   -> Details about 'object'. ?object also works, ?? prints more.
 def start(user_ns=None):
     # Make sure the log level is changed to warning
     CodecFactory()
-    taurus.setLogLevel(taurus.Warning)
+    setLogLevel(Warning)
 
     try:
         check_requirements()
@@ -1103,7 +1131,7 @@ def prepare_cmdline(argv=None):
 
     ipython_dir = get_ipython_dir()
     try:
-        ProfileDir.find_profile_dir_by_name(ipython_dir, profile)
+        pd = ProfileDir.find_profile_dir_by_name(ipython_dir, profile)
     except ProfileDirError:
         r = ''
         while not r in ('y', 'n'):
@@ -1111,7 +1139,7 @@ def prepare_cmdline(argv=None):
                      "one now ([y]/n)? " % profile
             r = raw_input(prompt) or 'y'
         if r.lower() == 'y':
-            create_spock_profile(ipython_dir, session, profile)
+            create_spock_profile(ipython_dir, profile)
         else:
             sys.stdout.write('No spock profile was created. '
                              'Starting ipython with default profile...\n')
@@ -1121,25 +1149,19 @@ def prepare_cmdline(argv=None):
                 if arg.startswith('--profile='):
                     argv.remove(arg)
             return
+    else:
+        ipy_profile_dir = pd.location # directory with the spock profile
+        check_for_upgrade(ipy_profile_dir)
 
     if append_profile:
         argv.append("--profile=" + profile)
 
 
 def run():
+
     try:
-        try:
-            # IPython 4.x
-            from traitlets import Unicode
-            from qtconsole.rich_jupyter_widget import RichIPythonWidget
-            from qtconsole.qtconsoleapp import IPythonQtConsoleApp
-            # TODO: check if we can/should set IPythonQtConsoleApp.version
-        except:
-            # IPython <4.x
-            from IPython.utils.traitlets import Unicode
-            from IPython.qt.console.rich_ipython_widget import RichIPythonWidget
-            from IPython.qt.console.qtconsoleapp import IPythonQtConsoleApp
-            IPythonQtConsoleApp.version.default_value = release.version
+        from IPython.utils.traitlets import Unicode
+        from IPython.frontend.qt.console.rich_ipython_widget import RichIPythonWidget
         
         class SpockConsole(RichIPythonWidget):
 
@@ -1149,8 +1171,10 @@ def run():
                 config = get_config()
                 return config.FrontendWidget.banner
 
+        import IPython.frontend.qt.console.qtconsoleapp
+        IPythonQtConsoleApp = IPython.frontend.qt.console.qtconsoleapp.IPythonQtConsoleApp
         IPythonQtConsoleApp.widget_factory = SpockConsole
-
+        IPythonQtConsoleApp.version.default_value = release.version
     except ImportError:
         pass
 
