@@ -52,6 +52,12 @@ else:
     from sardana.taurus.core.tango.sardana.macroserver import BaseDoor, BaseMacroServer
     BaseGUIViewer = object
 
+try:
+    RUNNING_STATE = TaurusSWDevState.Running
+except RuntimeError:
+    # TODO: For Taurus 4 compatibility
+    from taurus.core import TaurusDevState
+    RUNNING_STATE = TaurusDevState.Ready
 
 class GUIViewer(BaseGUIViewer):
 
@@ -118,7 +124,9 @@ class GUIViewer(BaseGUIViewer):
                     local_file = remote_file
         else:
             local_directories = directory_map[scan_dir]
-            if isinstance(scan_file, (str, unicode)):
+            # local_directories may be either a string or a list of strings
+            # the further logic is unified to work on a list, so convert it
+            if isinstance(local_directories, (str, unicode)):
                 local_directories = [local_directories]
             locations = local_directories
             if scan_dir not in locations: locations.append(scan_dir)
@@ -314,7 +322,7 @@ class SpockBaseDoor(BaseDoor):
 
     def _runMacro(self, xml, **kwargs):
         #kwargs like 'synch' are ignored in this re-implementation
-        if self._spock_state != TaurusSWDevState.Running:
+        if self._spock_state != RUNNING_STATE:
             print "Unable to run macro: No connection to door '%s'" % self.getSimpleName()
             raise Exception("Unable to run macro: No connection")
         if xml is None:
@@ -403,7 +411,7 @@ class SpockBaseDoor(BaseDoor):
 
     def _updateState(self, old_sw_state, new_sw_state, silent=False):
         user_ns = genutils.get_ipapi().user_ns
-        if new_sw_state == TaurusSWDevState.Running:
+        if new_sw_state == RUNNING_STATE:
             user_ns['DOOR_STATE'] = ""
         else:
             user_ns['DOOR_STATE'] = " (OFFLINE)"
@@ -414,9 +422,9 @@ class SpockBaseDoor(BaseDoor):
 
         ss = self._spock_state
         if ss is not None and ss != new_sw_state and not silent:
-            if ss == TaurusSWDevState.Running:
+            if ss == RUNNING_STATE:
                 self.write_asynch("\nConnection to door '%s' was lost.\n" % self.getSimpleName())
-            elif new_sw_state == TaurusSWDevState.Running:
+            elif new_sw_state == RUNNING_STATE:
                 self.write_asynch("\nConnection to the door (%s) has " \
                     "been restablished\n" % self.getSimpleName())
         self._spock_state = new_sw_state
@@ -563,13 +571,23 @@ class SpockMacroServer(BaseMacroServer):
     def _addMacro(self, macro_info):
         macro_name = str(macro_info.name)
 
-        def macro_fn(shell, parameter_s='', name=macro_name):
-            parameters = genutils.arg_split(parameter_s, posix=True)
-            door = genutils.get_door()
-            door.runMacro(macro_name, parameters, synch=True)
-            macro = door.getLastRunningMacro()
-            if macro is not None:  # maybe none if macro was aborted
-                return macro.getResult()
+        # IPython < 1 magic commands have different API
+        if genutils.get_ipython_version_list() < [1, 0]:
+            def macro_fn(shell, parameter_s='', name=macro_name):
+                parameters = genutils.arg_split(parameter_s, posix=True)
+                door = genutils.get_door()
+                door.runMacro(macro_name, parameters, synch=True)
+                macro = door.getLastRunningMacro()
+                if macro is not None:  # maybe none if macro was aborted
+                    return macro.getResult()
+        else:
+            def macro_fn(parameter_s='', name=macro_name):
+                parameters = genutils.arg_split(parameter_s, posix=True)
+                door = genutils.get_door()
+                door.runMacro(macro_name, parameters, synch=True)
+                macro = door.getLastRunningMacro()
+                if macro is not None:  # maybe none if macro was aborted
+                    return macro.getResult()
 
         macro_fn.func_name = macro_name
         macro_fn.__doc__ = macro_info.doc
