@@ -38,6 +38,7 @@ __docformat__ = 'restructuredtext'
 import os
 import sys
 import time
+import copy
 import weakref
 import operator
 import traceback
@@ -48,7 +49,12 @@ from PyTango import DevState, AttrDataFormat, AttrQuality, DevFailed, \
 from taurus import Factory, Device
 from taurus.core.taurusbasetypes import TaurusEventType, TaurusSWDevState, \
     TaurusSerializationMode
-from taurus.core.taurusvalidator import AttributeNameValidator
+try:
+    from taurus.core.taurusvalidator import AttributeNameValidator as\
+        TangoAttributeNameValidator
+except ImportError:
+    #TODO: For Taurus 4 compatibility
+    from taurus.core.tango.tangovalidator import TangoAttributeNameValidator
 from taurus.core.util.log import Logger
 from taurus.core.util.singleton import Singleton
 from taurus.core.util.codecs import CodecFactory
@@ -424,7 +430,6 @@ class PoolElement(BaseElement, TangoDevice):
         ts2 = evt_wait.getRecordedEvents().get(DevState.MOVING, ts2)
         return (ts2,)
 
-    @reservedOperation
     def waitFinish(self, timeout=None, id=None):
         if id is not None:
             id = id[0]
@@ -1155,12 +1160,20 @@ class MGConfiguration(object):
         self.non_tango_channels = n_tg_chs = CaselessDict()
         self.cache = cache = {}
 
-        tg_attr_validator = AttributeNameValidator()
+        tg_attr_validator = TangoAttributeNameValidator()
         for channel_name, channel_data in self.channels.items():
             cache[channel_name] = None
             data_source = channel_data['source']
             #external = ctrl_name.startswith("__")
+            # TODO: For Taurus 4 compatibility
+            # data_source of the sardana channels does not contain the scheme
+            # part but the external tango channels does.
+            # First try to use the original data_source and as the fallback
+            # complete it with the "tango://" part. If it fails, treat it as a
+            # NON tango channel.
             params = tg_attr_validator.getParams(data_source)
+            if params is None:
+                params = tg_attr_validator.getParams("tango://%s" % data_source)
             if params is None:
                 # Handle NON tango channel
                 n_tg_chs[channel_name] = channel_data
@@ -1249,17 +1262,42 @@ class MGConfiguration(object):
                 if ch_info.name.lower() == channel_name:
                     return d_name, a_name, ch_info
 
-    def getChannelsInfo(self):
+    def getChannelsInfo(self, only_enabled=False):
+        """Returns information about the channels present in the measurement
+        group in a form of dictionary, where key is a channel name and value is
+        a tuple of three elements:
+            - device name
+            - attribute name
+            - attribute information or None if there was an error trying to get
+              the information
+
+        :param only_enabled: flag to filter out disabled channels
+        :type only_enabled: bool
+        :return: dictionary with channels info
+        :rtype: dict<str, tuple<str, str, TangoChannelInfo>>
+        """
         self.prepare()
         ret = CaselessDict(self.tango_channels_info)
         ret.update(self.non_tango_channels)
+        for ch_name, (_, _, ch_info) in ret.items():
+            if only_enabled and not ch_info.enabled:
+                ret.pop(ch_name)
         return ret
 
-    def getChannelsInfoList(self):
-        channels_info = self.getChannelsInfo()
-        ret = len(channels_info) * [None]
+    def getChannelsInfoList(self, only_enabled=False):
+        """Returns information about the channels present in the measurement
+        group in a form of ordered, based on the channel index, list.
+
+        :param only_enabled: flag to filter out disabled channels
+        :type only_enabled: bool
+        :return: list with channels info
+        :rtype: list<TangoChannelInfo>
+        """
+        channels_info = self.getChannelsInfo(only_enabled=only_enabled)
+        ret = []
         for _, (_, _, ch_info) in channels_info.items():
-            ret[ch_info.index] = ch_info
+            ret.append(ch_info)
+        ret = sorted(ret, lambda x,y: cmp(x.index, y.index))
         return ret
 
     def getCountersInfoList(self):
@@ -1273,6 +1311,29 @@ class MGConfiguration(object):
             channels_info.pop(idx)
         return channels_info
 
+    def getTangoDevChannels(self, only_enabled=False):
+        """Returns Tango channels (attributes) that could be used to read
+        measurement group results in a form of dict where key is a device name
+        and value is a list with two elements:
+            - A device proxy or None if there was an error building it
+            - A dict where keys are attribute names and value is a reference to
+              a dict representing channel data as received in raw data
+
+        :param only_enabled: flag to filter out disabled channels
+        :type only_enabled: bool
+        :return: dict with Tango channels
+        :rtype: dict<str, list[DeviceProxy, CaselessDict<str, dict>]>
+        """
+        if not only_enabled:
+            return self.tango_dev_channels
+        tango_dev_channels = copy.deepcopy(self.tango_dev_channels)
+        for _, dev_data in tango_dev_channels.items():
+            _, attrs = dev_data
+            for attr_name, channel_data in attrs.items():
+                if not channel_data["enabled"]:
+                    attrs.pop(attr_name)
+        return tango_dev_channels
+
     def read(self, parallel=True):
         if parallel:
             return self._read_parallel()
@@ -1284,7 +1345,8 @@ class MGConfiguration(object):
         dev_replies = {}
 
         # deposit read requests
-        for _, dev_data in self.tango_dev_channels.items():
+        tango_dev_channels = self.getTangoDevChannels(only_enabled=True)
+        for _, dev_data in tango_dev_channels.items():
             dev, attrs = dev_data
             if dev is None:
                 continue
@@ -1314,7 +1376,8 @@ class MGConfiguration(object):
     def _read(self):
         self.prepare()
         ret = CaselessDict(self.cache)
-        for _, dev_data in self.tango_dev_channels.items():
+        tango_dev_channels = self.getTangoDevChannels(only_enabled=True)
+        for _, dev_data in tango_dev_channels.items():
             dev, attrs = dev_data
             try:
                 data = dev.read_attributes(attrs.keys())
@@ -1425,6 +1488,16 @@ class MeasurementGroup(PoolElement):
     def getChannelsInfo(self):
         return self.getConfiguration().getChannelsInfoList()
 
+    def getChannelsEnabledInfo(self):
+        """Returns information about **only enabled** channels present in the
+        measurement group in a form of ordered, based on the channel index,
+        list.
+
+        :return: list with channels info
+        :rtype: list<TangoChannelInfo>
+        """
+        return self.getConfiguration().getChannelsInfoList(only_enabled=True)
+
     def getCountersInfo(self):
         return self.getConfiguration().getCountersInfoList()
 
@@ -1588,7 +1661,9 @@ class Pool(TangoDevice, MoveableSource):
             kwargs['_pool_data'] = data
             kwargs['_pool_obj'] = self
             return klass(**kwargs)
-        obj = Factory().getDevice(element_info.full_name, _pool_obj=self,
+        # TODO: For Taurus 4 compatibility
+        fullname = "tango://%s" % element_info.full_name
+        obj = Factory().getDevice(fullname, _pool_obj=self,
                                   _pool_data=data)
         return obj
 
