@@ -155,7 +155,7 @@ class ParamEditorModel(Qt.QAbstractItemModel):
             if index.column() == 0:
                 return Qt.QVariant(node.name())
             elif index.column() == 1:
-                return Qt.QVariant(node.value())
+                return Qt.QVariant(str(node.value()))
 
         return Qt.QVariant()
 
