@@ -59,7 +59,7 @@ class PoolChannelTV(TaurusValue):
     '''
     def __init__(self, parent=None, designMode=False):
         TaurusValue.__init__(self, parent=parent, designMode=designMode)
-        self.setLabelWidgetClass("LabelWidgetDragsDeviceAndAttribute")
+        self.setLabelWidgetClass(LabelWidgetDragsDeviceAndAttribute)
         self.setLabelConfig('dev_alias')
 
     def getDefaultExtraWidgetClass(self):
