@@ -382,7 +382,9 @@ class ExpDescriptionEditor(Qt.QWidget, TaurusBaseWidget):
             else:
                 full_name = nfo.full_name; display = nfo.name
             # TODO: For Taurus 4 compatibility
-            preScanList.append((full_name.lstrip("tango://"), display))
+            if full_name.startswith("tango://"):
+                full_name = full_name[8:]
+            preScanList.append((full_name, display))
         self._localConfig['PreScanSnapshot'] = preScanList
         self._setDirty(True)
         
